pub struct ContractId(/* private fields */);Expand description
FuelVM atomic type.
Implementations
Sourceimpl ContractId
impl ContractId
Sourcepub const fn new(bytes: [u8; 32]) -> ContractId
pub const fn new(bytes: [u8; 32]) -> ContractId
Bytes constructor.
Sourcepub const fn zeroed() -> ContractId
pub const fn zeroed() -> ContractId
Zeroes bytes constructor.
Sourcepub unsafe fn from_slice_unchecked(bytes: &[u8]) -> ContractId
pub unsafe fn from_slice_unchecked(bytes: &[u8]) -> ContractId
Add a conversion from arbitrary slices into owned
Safety
This function will not panic if the length of the slice is smaller than
Self::LEN. Instead, it will cause undefined behavior and read random disowned
bytes
Sourcepub unsafe fn as_ref_unchecked(bytes: &[u8]) -> &ContractId
pub unsafe fn as_ref_unchecked(bytes: &[u8]) -> &ContractId
Sourceimpl ContractId
impl ContractId
Sourcepub const SEED: [u8; 4]
pub const SEED: [u8; 4]
Seed for the calculation of the contract id from its code.
https://github.com/FuelLabs/fuel-specs/blob/master/specs/protocol/identifiers.md#contract-id